#ifndef NT2_INCLUDE_FUNCTIONS_IS_NOT_IMAG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_NOT_IMAG_HPP_INCLUDED

#include <nt2/predicates/include/functions/is_not_imag.hpp>

#endif
